@@ -175,11 +175,12 @@ private:
     void removeAction(QAction* action)
     {
         ActionItem* item = findActionItemForAction(action);
-        if (item) {
-            delete item;
-        } else {
+        if (!item) {
             kWarning() << "No item for action" << action->text();
+            return;
         }
+        removeRow(item->row());
+        mNextActionItemRow--;
     }
 
     ActionItem* findActionItemForAction(QAction* action) const
