@@ -67,9 +67,6 @@ MessageIndicator::MessageIndicator(QObject* parent, const QVariantList& args)
 
     mSvg->setImagePath("icons/message-indicator");
     mSvg->setContainsMultipleImages(true);
-
-    setWidget(mStack);
-    updateStatus();
 }
 
 MessageIndicator::~MessageIndicator()
@@ -79,6 +76,9 @@ MessageIndicator::~MessageIndicator()
 
 void MessageIndicator::init()
 {
+    Plasma::Applet::init();
+    setWidget(mStack);
+
     Plasma::ToolTipManager::self()->registerWidget(this);
     connect(mListener,
             SIGNAL(serverAdded(QIndicate::Listener::Server*, const QString&)),
@@ -88,6 +88,8 @@ void MessageIndicator::init()
     initSourceModel();
     initView();
     initIcon();
+
+    updateStatus();
 }
 
 void MessageIndicator::initIcon()
@@ -101,7 +103,7 @@ void MessageIndicator::initIcon()
     updateStatus();
 }
 
-bool MessageIndicator::sceneEventFilter(QGraphicsItem*, QEvent* event)
+bool MessageIndicator::sceneEventFilter(QGraphicsItem* item, QEvent* event)
 {
     if (event->type() == QEvent::GraphicsSceneMousePress) {
         return true;
@@ -118,7 +120,7 @@ bool MessageIndicator::sceneEventFilter(QGraphicsItem*, QEvent* event)
         }
         return true;
     }
-    return false;
+    return Plasma::PopupApplet::sceneEventFilter(item, event);
 }
 
 void MessageIndicator::initSourceModel()
