@@ -39,6 +39,9 @@ public Q_SLOTS:
 
 protected:
     virtual void popupEvent(bool show);
+    virtual bool sceneEventFilter(QGraphicsItem*, QEvent* event);
+    virtual void constraintsEvent(Plasma::Constraints);
+    virtual void paintInterface(QPainter*, const QStyleOptionGraphicsItem*, const QRect&);
 
 private Q_SLOTS:
     void slotRowsChanged(const QModelIndex& parent);
@@ -48,15 +51,16 @@ private Q_SLOTS:
     void dumpModels();
     void initPalette();
     void adjustViewSize();
+    void activateLatestIndicator();
 
 private:
     QIndicate::Listener* mListener;
     ListenerModel* mSourceModel;
     QWidget* mStack;
     QTreeView* mView;
+    Plasma::Svg* mSvg;
     QLabel* mNoIndicatorLabel;
     QWidget* mCurrentWidget;
-    Plasma::IconWidget* mIconWidget;
 
     void initIcon();
     void initSourceModel();
